@@ -1,9 +1,9 @@
 """
-@Author: ChenXiaolei
-@Date: 2020-03-24 10:42:34
-@LastEditTime: 2020-12-14 10:46:13
-@LastEditors: ChenXiaolei
-@Description: StudioBaseHandler
+:Author: ChenXiaolei
+:Date: 2020-03-24 10:42:34
+:LastEditTime: 2020-12-25 10:04:58
+:LastEditors: ChenXiaolei
+:Description: StudioBaseHandler
 """
 
 from seven_framework.web_tornado.base_handler.base_cookie_handler import *
@@ -21,10 +21,10 @@ from seven_studio.models.enum import *
 
 class StudioBaseHandler(BaseCookieHandler):
     """
-    @description: StudioBaseHandler
-    @param {type} 
-    @return: 
-    @last_editors: HuangJingCan
+    :description: StudioBaseHandler
+    :param {type} 
+    :return: 
+    :last_editors: HuangJingCan
     """
     def options_async(self):
         self.reponse_json_success()
@@ -34,10 +34,10 @@ class StudioBaseHandler(BaseCookieHandler):
 
     def json_dumps(self, rep_dic):
         """
-        @description: 用于将字典形式的数据转化为字符串
-        @param rep_dic：字典对象
-        @return: str
-        @last_editors: HuangJingCan
+        :description: 用于将字典形式的数据转化为字符串
+        :param rep_dic：字典对象
+        :return: str
+        :last_editors: HuangJingCan
         """
         if hasattr(rep_dic, '__dict__'):
             rep_dic = rep_dic.__dict__
@@ -45,21 +45,21 @@ class StudioBaseHandler(BaseCookieHandler):
 
     def reponse_custom(self, rep_dic):
         """
-        @description: 输出公共json模型
-        @param rep_dic: 字典类型数据
-        @return: 将dumps后的数据字符串返回给客户端
-        @last_editors: HuangJingCan
+        :description: 输出公共json模型
+        :param rep_dic: 字典类型数据
+        :return: 将dumps后的数据字符串返回给客户端
+        :last_editors: HuangJingCan
         """
         self.http_reponse(self.json_dumps(rep_dic))
 
     def reponse_common(self, result_code, result_message, data=None):
         """
-        @description: 输出公共json模型
-        @param result_code: 字符串，服务端返回的错误码
-        @param result_message: 字符串，服务端返回的错误信息
-        @param data: 返回结果对象，即为数组，字典
-        @return: 将dumps后的数据字符串返回给客户端
-        @last_editors: HuangJingCan
+        :description: 输出公共json模型
+        :param result_code: 字符串，服务端返回的错误码
+        :param result_message: 字符串，服务端返回的错误信息
+        :param data: 返回结果对象，即为数组，字典
+        :return: 将dumps后的数据字符串返回给客户端
+        :last_editors: HuangJingCan
         """
         if hasattr(data, '__dict__'):
             data = data.__dict__
@@ -72,37 +72,37 @@ class StudioBaseHandler(BaseCookieHandler):
 
     def reponse_json_success(self, data=None, desc='调用成功'):
         """
-        @description: 通用成功返回json结构
-        @param data: 返回结果对象，即为数组，字典
-        @param desc: 字符串，服务端返回的错误信息
-        @return: 将dumps后的数据字符串返回给客户端
-        @last_editors: HuangJingCan
+        :description: 通用成功返回json结构
+        :param data: 返回结果对象，即为数组，字典
+        :param desc: 字符串，服务端返回的错误信息
+        :return: 将dumps后的数据字符串返回给客户端
+        :last_editors: HuangJingCan
         """
         self.reponse_common("0", desc, data)
 
     def reponse_json_error(self, desc='error'):
         """
-        @description: 通用错误返回json结构
-        @param desc: 字符串，服务端返回的错误信息
-        @return: 将dumps后的数据字符串返回给客户端
-        @last_editors: HuangJingCan
+        :description: 通用错误返回json结构
+        :param desc: 字符串，服务端返回的错误信息
+        :return: 将dumps后的数据字符串返回给客户端
+        :last_editors: HuangJingCan
         """
         self.reponse_common("1", desc)
 
     def reponse_json_error_params(self, desc='params error'):
         """
-        @description: 参数错误返回json结构
-        @param desc: 字符串，服务端返回的错误信息
-        @return: 将dumps后的数据字符串返回给客户端
-        @last_editors: HuangJingCan
+        :description: 参数错误返回json结构
+        :param desc: 字符串，服务端返回的错误信息
+        :return: 将dumps后的数据字符串返回给客户端
+        :last_editors: HuangJingCan
         """
         self.reponse_common("1", desc)
 
     def redis_init(self, db=None):
         """
-        @description: redis初始化
-        @return: redis_cli
-        @last_editors: HuangJingCan
+        :description: redis初始化
+        :return: redis_cli
+        :last_editors: HuangJingCan
         """
         host = config.get_value("redis")["host"]
         port = config.get_value("redis")["port"]
@@ -249,12 +249,12 @@ class StudioBaseHandler(BaseCookieHandler):
 
     def get_dict_page_info_list(self, page_index, page_size, p_dict, total=0):
         """
-        @description: 获取分页信息
-        @param page_index：页索引
-        @param page_size：页大小
-        @param p_dict：字典列表
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取分页信息
+        :param page_index：页索引
+        :param page_size：页大小
+        :param p_dict：字典列表
+        :return: 
+        :last_editors: HuangJingCan
         """
         page_info = PageInfo()
         page_info.PageIndex = page_index
@@ -266,11 +266,11 @@ class StudioBaseHandler(BaseCookieHandler):
 
     def get_dict_by_keys(self, source_dict, keys):
         """
-        @description: 根据key搜索字典，返回key相关字典
-        @param source_dict
-        @param keys
-        @return: 值
-        @last_editors: HuangJingCan
+        :description: 根据key搜索字典，返回key相关字典
+        :param source_dict
+        :param keys
+        :return: 值
+        :last_editors: HuangJingCan
         """
         if isinstance(source_dict, str):
             source_dict = json.loads(source_dict)
@@ -283,10 +283,10 @@ class StudioBaseHandler(BaseCookieHandler):
 
     def get_condition_by_body(self):
         """
-        @description: 获取页面查询条件
-        @param {type} 
-        @return: condition, order
-        @last_editors: HuangJingCan
+        :description: 获取页面查询条件
+        :param {type} 
+        :return: condition, order
+        :last_editors: HuangJingCan
         """
         condition = ""
         order = ""
@@ -327,10 +327,10 @@ class StudioBaseHandler(BaseCookieHandler):
 
     def get_system_user_table(self):
         """
-        @description: 获取系统用户
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取系统用户
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         user_dict = UserInfoModel(
             self.get_manage_context_key()).get_dict_list()
@@ -338,10 +338,10 @@ class StudioBaseHandler(BaseCookieHandler):
 
     def logout(self, user_id):
         """
-        @description: 用户退出
-        @param user_id：用户id
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 用户退出
+        :param user_id：用户id
+        :return: 
+        :last_editors: HuangJingCan
         """
         if user_id.strip() == "":
             return
@@ -357,11 +357,11 @@ class StudioBaseHandler(BaseCookieHandler):
 
     def check_power_menu(self, api_path, cote_id):
         """
-        @description: 权限判断
-        @param api_path：路径
-        @param cote_id：权限码值
-        @return: True or False
-        @last_editors: HuangJingCan
+        :description: 权限判断
+        :param api_path：路径
+        :param cote_id：权限码值
+        :return: True or False
+        :last_editors: HuangJingCan
         """
         manage_context_key = self.get_manage_context_key()
         menu_info_list = MenuInfoModel(manage_context_key).get_list(
@@ -383,10 +383,10 @@ class StudioBaseHandler(BaseCookieHandler):
 
     def auto_mapper(self, s_model, map_dict=None):
         """
-        @description: 对象映射（把map_dict值赋值到实体s_model中）
-        @param s_model：需要映射的实体对象
-        @param map_dict：被映射的实体字典
-        @return: 映射后的实体s_model
+        :description: 对象映射（把map_dict值赋值到实体s_model中）
+        :param s_model：需要映射的实体对象
+        :param map_dict：被映射的实体字典
+        :return: 映射后的实体s_model
         """
         if map_dict:
             field_list = s_model.get_field_list()
@@ -398,10 +398,10 @@ class StudioBaseHandler(BaseCookieHandler):
 
 def login_filter(is_need_login=True, optional_params=None):
     """
-    @description: 登陆过滤装饰器 仅限handler使用
-    @param is_need_login：是否需要登陆
-    @param optional_params：其他参数
-    @return: handler
+    :description: 登陆过滤装饰器 仅限handler使用
+    :param is_need_login：是否需要登陆
+    :param optional_params：其他参数
+    :return: handler
     """
     def check_login(handler):
         def wrapper(self, **args):
