@@ -1,9 +1,9 @@
 """
-@Author: HuangJingCan
-@Date: 2020-03-24 19:48:05
-@LastEditTime: 2020-12-14 10:47:10
-@LastEditors: ChenXiaolei
-@Description: 
+:Author: HuangJingCan
+:Date: 2020-03-24 19:48:05
+:LastEditTime: 2020-12-25 10:04:18
+:LastEditors: ChenXiaolei
+:Description: 
 """
 from seven_studio.handlers.studio_base import *
 from seven_studio.libs.geetest import *
@@ -24,7 +24,7 @@ class CoreHandler(StudioBaseHandler):
 
 class GeetestCodeHandler(StudioBaseHandler):
     """
-    @description: 获取极验证的验证码
+    :description: 获取极验证的验证码
     """
     def get_async(self):
         user_id = 'test'
@@ -39,7 +39,7 @@ class GeetestCodeHandler(StudioBaseHandler):
 
 class LoginPlatformHandler(StudioBaseHandler):
     """
-    @description: 登陆
+    :description: 登陆
     """
     def get_async(self):
         account = self.get_param("account")
@@ -66,12 +66,12 @@ class LoginPlatformHandler(StudioBaseHandler):
 
     def check_code(self, challenge="", validate="", seccode=""):
         """
-        @description: 验证码校验
-        @param challenge：challenge
-        @param validate：validate
-        @param seccode：seccode
-        @return: true or false
-        @last_editors: HuangJingCan
+        :description: 验证码校验
+        :param challenge：challenge
+        :param validate：validate
+        :param seccode：seccode
+        :return: true or false
+        :last_editors: HuangJingCan
         """
         gt = GeetestLib(config.get_value("pc_geetest_id"), config.get_value("pc_geetest_key"))
         result = gt.success_validate(challenge, validate, seccode, JSON_FORMAT=0)
@@ -79,12 +79,12 @@ class LoginPlatformHandler(StudioBaseHandler):
 
     def login(self, account="", password="", is_platform=False):
         """
-        @description: 登录验证
-        @param account：账号
-        @param password：密码
-        @param is_platform：是否平台用户
-        @return: invoke_result
-        @last_editors: HuangJingCan
+        :description: 登录验证
+        :param account：账号
+        :param password：密码
+        :param is_platform：是否平台用户
+        :return: invoke_result
+        :last_editors: HuangJingCan
         """
         manage_context_key = config.get_value("manage_context_key")
         base_manage_context_key = config.get_value("base_manage_context_key")
@@ -156,10 +156,10 @@ class LoginPlatformHandler(StudioBaseHandler):
 
     def set_user_info_login_status(self, user_info):
         """
-        @description: 登录状态设置
-        @param user_info：当前登录用户信息
-        @return: user_login
-        @last_editors: HuangJingCan
+        :description: 登录状态设置
+        :param user_info：当前登录用户信息
+        :return: user_login
+        :last_editors: HuangJingCan
         """
         user_login = UserLogin()
         user_login.UserID = user_info.UserID
@@ -185,14 +185,14 @@ class LoginPlatformHandler(StudioBaseHandler):
 
 class LogoutHandler(StudioBaseHandler):
     """
-    @description: 注销
+    :description: 注销
     """
     def post_async(self):
         """
-        @description: 注销用户
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 注销用户
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         self.logout(self.request_user_id())
 
@@ -201,15 +201,15 @@ class LogoutHandler(StudioBaseHandler):
 
 class UploadFilesHandler(StudioBaseHandler):
     """
-    @description: 上传图片
+    :description: 上传图片
     """
     def post_async(self):
         """
-        @description: 上传图片
-        @param resourceCode：resourceCode
-        @param resourceCode：restrictCode
-        @return: json
-        @last_editors: HuangJingCan
+        :description: 上传图片
+        :param resourceCode：resourceCode
+        :param resourceCode：restrictCode
+        :return: json
+        :last_editors: HuangJingCan
         """
         # 获取参数
         resource_code = self.get_param("resourceCode")
