@@ -1,9 +1,9 @@
 """
-@Author: wang kui
-@Date: 2020-03-24 16:32:52
-@LastEditTime: 2020-12-14 11:30:43
-@LastEditors: ChenXiaolei
-@Description: power 用户权限相关接口
+:Author: wang kui
+:Date: 2020-03-24 16:32:52
+:LastEditTime: 2020-12-14 11:30:43
+:LastEditors: ChenXiaolei
+:Description: power 用户权限相关接口
 """
 from seven_studio.handlers.studio_base import *
 from seven_studio.utils.dict import *
@@ -21,15 +21,15 @@ from seven_studio.models.power_model import *
 
 class GetUserInfoHandler(StudioBaseHandler):
     """
-    @description: 获取当前用户信息
+    :description: 获取当前用户信息
     """
     @login_filter(True)
     def get_async(self):
         """
-        @description: 获取当前用户信息
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取当前用户信息
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         user_info = self.get_curr_user_info()
         curr_info = {}
@@ -45,15 +45,15 @@ class GetUserInfoHandler(StudioBaseHandler):
 
 class GetUserProductListHandler(StudioBaseHandler):
     """
-    @description: 获取用户产品列表
+    :description: 获取用户产品列表
     """
     @login_filter(True)
     def get_async(self):
         """
-        @description: 获取用户产品列表
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取用户产品列表
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         user_id = self.request_user_id()
         product_id = self.request_product_id()
@@ -103,10 +103,10 @@ class GetUserProductListHandler(StudioBaseHandler):
 
     def __to_user_product_data(self, user_id, product_info, is_super):
         """
-        @description: 判断该用户是否有用户管理和角色管理权限
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 判断该用户是否有用户管理和角色管理权限
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         has_user_manage = False
         has_role_manage = False
@@ -146,10 +146,10 @@ class GetUserProductListHandler(StudioBaseHandler):
 
     def __has_home_platform_power(self, user_info):
         """
-        @description: 获取该账号是否有平台管理权限
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取该账号是否有平台管理权限
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         invoke_result = InvokeResult()
         invoke_result.ResultCode = "AccountLock"
@@ -179,15 +179,15 @@ class GetUserProductListHandler(StudioBaseHandler):
 
 class FocusPasswordHandler(StudioBaseHandler):
     """
-    @description: 强制修改密码弹窗
+    :description: 强制修改密码弹窗
     """
     @login_filter(True)
     def get_async(self):
         """
-        @description: 强制修改密码弹窗
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 强制修改密码弹窗
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         invoke_result = InvokeResult()
         is_force_password = UserInfoModelEx().is_force_password(
@@ -201,15 +201,15 @@ class FocusPasswordHandler(StudioBaseHandler):
 
 class FocusChangeUserPwHandler(StudioBaseHandler):
     """
-    @description: 强制修改密码
+    :description: 强制修改密码
     """
     @login_filter(True)
     def post_async(self):
         """
-        @description: 强制修改密码
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 强制修改密码
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         invoke_result = InvokeResult()
         password = self.get_param("password")
@@ -235,15 +235,15 @@ class FocusChangeUserPwHandler(StudioBaseHandler):
 
 class ChangeCurrUserPwHandler(StudioBaseHandler):
     """
-    @description: 修改密码
+    :description: 修改密码
     """
     @login_filter(True)
     def post_async(self):
         """
-        @description: 修改密码
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 修改密码
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         invoke_result = InvokeResult()
         password = self.get_param("Password")
@@ -269,15 +269,15 @@ class ChangeCurrUserPwHandler(StudioBaseHandler):
 
 class GetRoleListHandler(StudioBaseHandler):
     """
-    @description: 角色列表
+    :description: 角色列表
     """
     @login_filter(True)
     def get_async(self):
         """
-        @description: 角色列表
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 角色列表
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         manage_context_key = self.get_manage_context_key()
         user_id = self.request_user_id()
@@ -295,16 +295,16 @@ class GetRoleListHandler(StudioBaseHandler):
 
 class GetRoleUserListHandler(StudioBaseHandler):
     """
-    @description: 角色用户列表
+    :description: 角色用户列表
     """
     @login_filter(True)
     @power_filter(True)
     def post_async(self):
         """
-        @description: 角色用户列表
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 角色用户列表
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         manage_context_key = self.get_manage_context_key()
         user_id = self.request_user_id()
@@ -373,15 +373,15 @@ class GetRoleUserListHandler(StudioBaseHandler):
 
 class GetUserRoleListHandler(StudioBaseHandler):
     """
-    @description: 用户角色列表
+    :description: 用户角色列表
     """
     @login_filter(True)
     def post_async(self):
         """
-        @description: 用户角色列表
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 用户角色列表
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         manage_context_key = self.get_manage_context_key()
         product_id = config.get_value("product_id")
@@ -453,15 +453,15 @@ class GetUserRoleListHandler(StudioBaseHandler):
 
 class SaveUserHandler(StudioBaseHandler):
     """
-    @description: 保存用户
+    :description: 保存用户
     """
     @login_filter(True)
     def post_async(self):
         """
-        @description: 保存用户
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 保存用户
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         # 获取参数
         user_id = self.get_param("UserID")
@@ -524,15 +524,15 @@ class SaveUserHandler(StudioBaseHandler):
 
 class SaveCurrUserHandler(StudioBaseHandler):
     """
-    @description: 保存用户
+    :description: 保存用户
     """
     @login_filter(True)
     def post_async(self):
         """
-        @description: 保存用户
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 保存用户
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         # 获取参数
         user_id = self.request_user_id()
@@ -564,15 +564,15 @@ class SaveCurrUserHandler(StudioBaseHandler):
 
 class GetUserListHandler(StudioBaseHandler):
     """
-    @description: 用户列表
+    :description: 用户列表
     """
     @login_filter(True)
     def get_async(self):
         """
-        @description: 用户列表
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 用户列表
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         manage_context_key = self.get_manage_context_key()
         user_id = self.request_user_id()
@@ -590,16 +590,16 @@ class GetUserListHandler(StudioBaseHandler):
 
 class SaveRoleHandler(StudioBaseHandler):
     """
-    @description: 修改角色
+    :description: 修改角色
     """
     @login_filter(True)
     @power_filter(True)
     def post_async(self):
         """
-        @description: 修改角色
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 修改角色
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         # 获取参数
         role_id = self.get_param("RoleID")
@@ -654,16 +654,16 @@ class SaveRoleHandler(StudioBaseHandler):
 
 class RemoveRoleUserHandler(StudioBaseHandler):
     """
-    @description: 删除用户角色
+    :description: 删除用户角色
     """
     @login_filter(True)
     @power_filter(True)
     def get_async(self):
         """
-        @description: 删除用户角色
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 删除用户角色
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         manage_context_key = self.get_manage_context_key()
         is_super = self.get_is_super()
@@ -686,16 +686,16 @@ class RemoveRoleUserHandler(StudioBaseHandler):
 
 class DeleteRoleHandler(StudioBaseHandler):
     """
-    @description: 删除角色
+    :description: 删除角色
     """
     @login_filter(True)
     @power_filter(True)
     def get_async(self):
         """
-        @description: 删除用户角色
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 删除用户角色
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         role_id = self.get_param("RoleID")
 
@@ -713,17 +713,17 @@ class DeleteRoleHandler(StudioBaseHandler):
 
 class DeleteUserHandler(StudioBaseHandler):
     """
-    @description: 删除用户
+    :description: 删除用户
     """
     @login_filter(True)
     @power_filter(True)
     @filter_check_params("UserID")
     def get_async(self):
         """
-        @description: 删除用户
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 删除用户
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         user_id = self.get_param("UserID")
 
@@ -749,17 +749,17 @@ class DeleteUserHandler(StudioBaseHandler):
 
 class ModifyUserStatusHandler(StudioBaseHandler):
     """
-    @description: 更新用户状态
+    :description: 更新用户状态
     """
     @login_filter(True)
     @power_filter(True)
     @filter_check_params("UserID,IsLock")
     def get_async(self):
         """
-        @description: 更新用户状态
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 更新用户状态
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         user_id = self.get_param("UserID")
         is_lock = int(self.get_param("IsLock", -1))
@@ -790,17 +790,17 @@ class ModifyUserStatusHandler(StudioBaseHandler):
 
 class ResetUserPasswordHandler(StudioBaseHandler):
     """
-    @description: 重置密码
+    :description: 重置密码
     """
     @login_filter(True)
     @power_filter(True)
     @filter_check_params("UserID")
     def get_async(self):
         """
-        @description: 重置密码
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 重置密码
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         user_id = self.get_param("UserID")
         curr_user_id = self.request_user_id()
@@ -828,17 +828,17 @@ class ResetUserPasswordHandler(StudioBaseHandler):
 
 class ResetUserFaildLoginCountHandler(StudioBaseHandler):
     """
-    @description: 登录失败重置
+    :description: 登录失败重置
     """
     @login_filter(True)
     @power_filter(True)
     @filter_check_params("UserID")
     def get_async(self):
         """
-        @description: 登录失败重置
-        @param {type}
-        @return:
-        @last_editors: HuangJingCan
+        :description: 登录失败重置
+        :param {type}
+        :return:
+        :last_editors: HuangJingCan
         """
         user_id = self.get_param("UserID")
         curr_user_id = self.request_user_id()
@@ -862,17 +862,17 @@ class ResetUserFaildLoginCountHandler(StudioBaseHandler):
 
 class RemoveUserAllRoleHandler(StudioBaseHandler):
     """
-    @description: 收回权限
+    :description: 收回权限
     """
     # @login_filter(True)
     # @power_filter(True)
     @filter_check_params("UserID")
     def get_async(self):
         """
-        @description: 收回权限
-        @param {type}
-        @return:
-        @last_editors: HuangJingCan
+        :description: 收回权限
+        :param {type}
+        :return:
+        :last_editors: HuangJingCan
         """
         user_id = self.get_param("UserID")
         curr_user_id = self.request_user_id()
@@ -893,17 +893,17 @@ class RemoveUserAllRoleHandler(StudioBaseHandler):
 
 class CopyUserRoleHandler(StudioBaseHandler):
     """
-    @description: 复制权限
+    :description: 复制权限
     """
     # @login_filter(True)
     # @power_filter(True)
     @filter_check_params("userID,copyUserID")
     def get_async(self):
         """
-        @description: 复制权限
-        @param {type}
-        @return:
-        @last_editors: HuangJingCan
+        :description: 复制权限
+        :param {type}
+        :return:
+        :last_editors: HuangJingCan
         """
         copy_user_id = self.get_param("copyUserID")
         user_id = self.get_param("userID")
