@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-04-29 11:00:52
+:Author: HuangJingCan
+:Date: 2020-04-29 11:00:52
 :LastEditTime: 2020-12-15 18:25:44
 :LastEditors: ChenXiaolei
-@Description: 文件上传信息
+:Description: 文件上传信息
 """
 from PIL import Image
 from io import BytesIO
@@ -25,10 +25,10 @@ from seven_studio.models.db_models.file.file_history_model import *
 
 class FileUpload():
     """
-    @description: 文件相关操作类
-    @param {type} 
-    @return: 
-    @last_editors: HuangJingCan
+    :description: 文件相关操作类
+    :param {type} 
+    :return: 
+    :last_editors: HuangJingCan
     """
 
     def __init__(self, file_context_key='db_sevenstudio'):
@@ -36,12 +36,12 @@ class FileUpload():
 
     def upload(self, resource_code, restrict_code, dict_file):
         """
-        @description: 文件上传
-        @param resource_code：资源代码
-        @param restrict_code：资源限制码
-        @param dict_file：字典文件信息
-        @return: InvokeResult
-        @last_editors: HuangJingCan
+        :description: 文件上传
+        :param resource_code：资源代码
+        :param restrict_code：资源限制码
+        :param dict_file：字典文件信息
+        :return: InvokeResult
+        :last_editors: HuangJingCan
         """
         invoke_result = InvokeResult()
 
@@ -89,10 +89,10 @@ class FileUpload():
                     horizontal_align=0,
                     vertical_align=0):
         """
-        @description: 文件上传
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 文件上传
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         invoke_result = InvokeResult()
         file_upload_info = FileUploadInfo()
@@ -128,10 +128,10 @@ class FileUpload():
 
     def __to_file_size(self, size):
         """
-        @description: 文件大小格式化
-        @param size：文件大小
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 文件大小格式化
+        :param size：文件大小
+        :return: 
+        :last_editors: HuangJingCan
         """
         if size < 1000:
             return '%i' % size + 'size'
@@ -146,10 +146,10 @@ class FileUpload():
 
     def switch_upload(self, stream, file_name, file_restrict):
         """
-        @description: 文件上传
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 文件上传
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         invoke_result = InvokeResult()
         file_upload_info = FileUploadInfo()
@@ -269,10 +269,10 @@ class FileUpload():
     def get_resource_path_format_value(self, create_date_time, resource_ver_id,
                                        path_format_code_id):
         """
-        @description: 获取附件路径格式值规则
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取附件路径格式值规则
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         result = ""
         if path_format_code_id == 0:
@@ -289,10 +289,10 @@ class FileUpload():
                          resource_code, path_format_value,
                          resource_uuid_file_name, resource_file_name):
         """
-        @description: 获取资源网址规则 [组合附件网址]
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取资源网址规则 [组合附件网址]
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         resource_url = ""
         uuid_file_name = os.path.splitext(resource_uuid_file_name)[0]
@@ -318,10 +318,10 @@ class FileUpload():
                                          resource_file_name,
                                          is_create_directory=True):
         """
-        @description: 获取附件完整文件名规则 [组合完整文件名]
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取附件完整文件名规则 [组合完整文件名]
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         resource_directory = ""
         if storage_path == "":
@@ -344,10 +344,10 @@ class FileUpload():
                                     resource_code, path_format_value,
                                     resource_uuid_file_name):
         """
-        @description: 获取资源目录规则
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取资源目录规则
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         resource_directory = ""
         if path_format_value != "":
